Struct Kind
pub struct Kind(/* private fields */);wayland and Linux only.Expand description
bitmask of flags in presented event
These flags provide information about how the presentation of the related content update was done. The intent is to help clients assess the reliability of the feedback and the visual quality with respect to possible tearing and timings.
Implementations
impl Kind
impl Kind
pub const Vsync: Kind
pub const Vsync: Kind
presentation was vsync’d
The presentation was synchronized to the “vertical retrace” by the display hardware such that tearing does not happen. Relying on software scheduling is not acceptable for this flag. If presentation is done by a copy to the active frontbuffer, then it must guarantee that tearing cannot happen.
pub const HwClock: Kind
pub const HwClock: Kind
hardware provided the presentation timestamp
The display hardware provided measurements that the hardware driver converted into a presentation timestamp. Sampling a clock in software is not acceptable for this flag.
pub const HwCompletion: Kind
pub const HwCompletion: Kind
hardware signalled the start of the presentation
The display hardware signalled that it started using the new image content. The opposite of this is e.g. a timer being used to guess when the display hardware has switched to the new image content.
pub const ZeroCopy: Kind
pub const ZeroCopy: Kind
presentation was done zero-copy
The presentation of this update was done zero-copy. This means the buffer from the client was given to display hardware as is, without copying it. Compositing with OpenGL counts as copying, even if textured directly from the client buffer. Possible zero-copy cases include direct scanout of a fullscreen surface and a surface on a hardware overlay.
impl Kind
impl Kind
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Kind>
pub const fn from_bits(bits: u32) -> Option<Kind>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Kind
pub const fn from_bits_truncate(bits: u32) -> Kind
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Kind
pub const fn from_bits_retain(bits: u32) -> Kind
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Kind>
pub fn from_name(name: &str) -> Option<Kind>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Kind) -> bool
pub const fn intersects(&self, other: Kind) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Kind) -> bool
pub const fn contains(&self, other: Kind) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Kind)
pub fn remove(&mut self, other: Kind)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Kind, value: bool)
pub fn set(&mut self, other: Kind, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Kind) -> Kind
pub const fn intersection(self, other: Kind) -> Kind
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: Kind) -> Kind
pub const fn difference(self, other: Kind) -> Kind
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Kind) -> Kind
pub const fn symmetric_difference(self, other: Kind) -> Kind
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Kind
pub const fn complement(self) -> Kind
The bitwise negation (!) of the bits in self, truncating the result.
impl Kind
impl Kind
pub const fn iter(&self) -> Iter<Kind>
pub const fn iter(&self) -> Iter<Kind>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Kind>
pub const fn iter_names(&self) -> IterNames<Kind>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.